# dhtioc

Provide humidity and temperature using EPICS and Raspberry Pi.

Uses

*   DHT22 sensor
*   Raspberry Pi
*   EPICS caproto IOC

[![Python version](https://img.shields.io/pypi/pyversions/dhtioc.svg)](https://pypi.python.org/pypi/dhtioc)
[![Documentation Status](https://readthedocs.org/projects/dhtioc/badge/?version=latest)](http://dhtioc.readthedocs.io/en/latest/?badge=latest)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/1411c74b1b8a4edb8ec70437339ad2b5)](https://app.codacy.com/manual/prjemian/dhtioc?utm_source=github.com&utm_medium=referral&utm_content=prjemian/dhtioc&utm_campaign=Badge_Grade_Dashboard)
